==> hn-main-referee-api-1.0-20250703.100540-41-sources.jar: com/beiming/odr/referee/dto/responsedto/LawCaseResponseDTO.java <==
package com.beiming.odr.referee.dto.responsedto;

import com.beiming.odr.referee.enums.CaseProgressEnum;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Transient;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @Description
 * @Author blake
 * @Date 2019-07-29 14:57
 * @Version 1.0
 */
@Data
@NoArgsConstructor
public class LawCaseResponseDTO implements Serializable {

  private Long lawCaseId;

  /**
   * 调解类型（人民调解，行政调解)
   */
  private String mediationType;

  /**
   * 案件录入人id
   */
  private Long creatorId;

  /**
   * 案件录入人的身份
   */
  private String creatorType;

  /**
   * 审批类型：1=延期；2=纠纷信息
   */
  private Integer approvalType;

  /**
   * 案件编号
   */
  private String caseNo;

  /**
   * 视频表id
   */
  private Long videoId;

  /**
   * 状态码(05纠纷被拒绝受理等)
   */
  private String lawCaseStatus;

  /**
   * 案件进度
   */
  private CaseProgressEnum caseProgress;

  /**
   * 咨询纠纷id，咨询转立案存入该值
   */
  private Long disputesId;

  /**
   * 纠纷类型字典表code
   */
  private String disputeTypeCode;

  /**
   * 纠纷类型
   */
  private String disputeType;

  /**
   * 省份code
   */
  private String provCode;

  /**
   * 城市code
   */
  private String cityCode;

  /**
   * 区code
   */
  private String areaCode;

  /**
   * 街道code
   */
  private String streetCode;

  /**
   * 省份名称
   */
  private String provName;

  /**
   * 城市名称
   */
  private String cityName;

  /**
   * 区名称
   */
  private String areaName;

  /**
   * 街道名称
   */
  private String streetName;

  /**
   * 社区code
   */
  private String communityCode;

  /**
   * 社区名称
   */
  private String communityName;

  /**
   * 详细地址
   */
  private String address;

  /**
   * 机构id
   */
  private Long orgId;

  /**
   * 机构名称
   */
  private String orgName;

  /**
   * 机构地区code
   */
  private String orgAreaCode;

  /**
   * 调解员id
   */
  private Long mediatorId;

  /**
   * 调解员名称
   */
  private String mediatorName;

  /**
   * 案件来源。本平台录入； 第三方平台导入。网上立案系统导入，律师平台导入
   */
  private String origin;

  /**
   * 机构业务负责人是否已经确认的字段(0：未确认 1：已确认)
   */
  private Boolean orgConfirm;

  /**
   * 调解开始时间
   */
  private Date startTime;

  /**
   * 调解结束时间
   */
  private Date endTime;

  /**
   * 案件完成时间
   */
  private Date caseCompleteTime;

  /**
   * 重新分配的标签
   */
  private String tab;

  /**
   * 选择性短信发送功能 0为发送，1为不发送
   */
  private Boolean smsOff;

  /**
   * 申请人诉求
   */
  private String appeal;

  /**
   * 纠纷描述
   */
  private String disputeContent;

  /**
   * 重新分配的详细内容
   */
  private String tabDetail;

  /**
   * 调解时间延长状态
   */
  @Transient
  private String extendStatus;

  /**
   * 调解时间延长确认状态
   */
  @Transient
  private String confirmStatus;
  /**
   * 调解时间延长天数
   */
  @Transient
  private Integer extendDay;
  /**
   * 延期原因
   */
  @Transient
  private String extendReason;
  /**
   * 调解期限
   */
  private Date mediationDeadline;
  /**
   * 延期表id
   */
  @Transient
  private Long extendId;

  /**
   * 是否终止过案件
   */
  private Boolean isSuspend;

  private Integer suspendNum;

  /**
   * 引调案件Id
   */
  private String citeCaseId;

  /**
   * 引调案件号
   */
  private String citeCaseName;

  private String citeCaseType;
  private String citeCaseFilingSeq;

  private String tdhCaseType;

  private String tdhApplicableProcedures;

  private String tdhAmount;

  private String disputeAmount;
}

==> hn-main-referee-api-1.0-20250925.090422-62-sources.jar: com/beiming/odr/referee/dto/responsedto/LawCaseResponseDTO.java <==
package com.beiming.odr.referee.dto.responsedto;

import com.beiming.odr.referee.enums.CaseProgressEnum;
import com.beiming.odr.referee.enums.ResolutionTypeEnum;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Transient;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @Description
 * @Author blake
 * @Date 2019-07-29 14:57
 * @Version 1.0
 */
@Data
@NoArgsConstructor
public class LawCaseResponseDTO implements Serializable {

  private Long lawCaseId;

  /**
   * 调解类型（人民调解，行政调解)
   */
  private String mediationType;

  /**
   * 案件录入人id
   */
  private Long creatorId;

  /**
   * 案件录入人的身份
   */
  private String creatorType;

  /**
   * 审批类型：1=延期；2=纠纷信息
   */
  private Integer approvalType;

  /**
   * 案件编号
   */
  private String caseNo;

  /**
   * 视频表id
   */
  private Long videoId;

  /**
   * 状态码(05纠纷被拒绝受理等)
   */
  private String lawCaseStatus;

  /**
   * 案件进度
   */
  private CaseProgressEnum caseProgress;

  /**
   * 咨询纠纷id，咨询转立案存入该值
   */
  private Long disputesId;

  /**
   * 纠纷类型字典表code
   */
  private String disputeTypeCode;

  /**
   * 纠纷类型
   */
  private String disputeType;

  /**
   * 省份code
   */
  private String provCode;

  /**
   * 城市code
   */
  private String cityCode;

  /**
   * 区code
   */
  private String areaCode;

  /**
   * 街道code
   */
  private String streetCode;

  /**
   * 省份名称
   */
  private String provName;

  /**
   * 城市名称
   */
  private String cityName;

  /**
   * 区名称
   */
  private String areaName;

  /**
   * 街道名称
   */
  private String streetName;

  /**
   * 社区code
   */
  private String communityCode;

  /**
   * 社区名称
   */
  private String communityName;

  /**
   * 详细地址
   */
  private String address;

  /**
   * 机构id
   */
  private Long orgId;

  /**
   * 机构名称
   */
  private String orgName;

  /**
   * 机构地区code
   */
  private String orgAreaCode;

  /**
   * 调解员id
   */
  private Long mediatorId;

  /**
   * 调解员名称
   */
  private String mediatorName;

  /**
   * 案件来源。本平台录入； 第三方平台导入。网上立案系统导入，律师平台导入
   */
  private String origin;

  /**
   * 机构业务负责人是否已经确认的字段(0：未确认 1：已确认)
   */
  private Boolean orgConfirm;

  /**
   * 调解开始时间
   */
  private Date startTime;

  /**
   * 调解结束时间
   */
  private Date endTime;

  /**
   * 案件完成时间
   */
  private Date caseCompleteTime;

  /**
   * 重新分配的标签
   */
  private String tab;

  /**
   * 选择性短信发送功能 0为发送，1为不发送
   */
  private Boolean smsOff;

  /**
   * 申请人诉求
   */
  private String appeal;

  /**
   * 纠纷描述
   */
  private String disputeContent;

  /**
   * 重新分配的详细内容
   */
  private String tabDetail;

  /**
   * 调解时间延长状态
   */
  @Transient
  private String extendStatus;

  /**
   * 调解时间延长确认状态
   */
  @Transient
  private String confirmStatus;
  /**
   * 调解时间延长天数
   */
  @Transient
  private Integer extendDay;
  /**
   * 延期原因
   */
  @Transient
  private String extendReason;
  /**
   * 调解期限
   */
  private Date mediationDeadline;
  /**
   * 延期表id
   */
  @Transient
  private Long extendId;

  /**
   * 是否终止过案件
   */
  private Boolean isSuspend;

  private Integer suspendNum;

  /**
   * 引调案件Id
   */
  private String citeCaseId;

  /**
   * 引调案件号
   */
  private String citeCaseName;

  private String citeCaseType;
  private String citeCaseFilingSeq;

  private String tdhCaseType;

  private String tdhApplicableProcedures;

  private String tdhAmount;

  private String disputeAmount;

  /**
   * 案件类型(mediate:调解；arbitration:仲裁；litigation:诉讼)
   */
  private ResolutionTypeEnum resolutionType;
}
